@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
 
 # See LICENSE.txt for licensing terms
-#$HeadURL: https://rst2pdf.googlecode.com/svn/tags/0.93/rst2pdf/extensions/dotted_toc.py $
-#$LastChangedDate: 2010-11-30 18:39:28 -0300 (Tue, 30 Nov 2010) $
-#$LastChangedRevision: 2417 $
 
 # Some fragments of code are copied from Reportlab under this license:
 #
@@ -38,16 +35,18 @@
 #####################################################################################
 
 from copy import copy
+
 import reportlab
-from reportlab.platypus.tableofcontents import drawPageNumbers
 import rst2pdf.genelements as genelements
+from reportlab.platypus import Spacer
+from reportlab.platypus.tableofcontents import drawPageNumbers
 
 Table = genelements.Table
 Paragraph = genelements.Paragraph
 
 '''
 
-.. NOTE:  
+.. NOTE:
 
     THIS IS A HUGE HACK HACK HACK
 
@@ -79,6 +78,7 @@ Mind you, the original RL implementation is a complete hack in any case:
     extremely easy to generate a unique name.
 '''
 
+
 class DottedTableOfContents(genelements.MyTableOfContents):
 
     toc_counter = [0]
@@ -120,9 +120,9 @@ class DottedTableOfContents(genelements.MyTableOfContents):
         for entry in _tempEntries:
             level, text, pageNum = entry[:3]
             left_col_level = level - base_level
-            if reportlab.Version > '2.3': # For ReportLab post-2.3
-                style=self.getLevelStyle(left_col_level)
-            else: # For ReportLab <= 2.3
+            if reportlab.Version > '2.3':  # For ReportLab post-2.3
+                style = self.getLevelStyle(left_col_level)
+            else:  # For ReportLab <= 2.3
                 style = self.levelStyles[left_col_level]
 
             if self.dotsMinLevel >= 0 and left_col_level >= self.dotsMinLevel:
@@ -141,12 +141,13 @@ class DottedTableOfContents(genelements.MyTableOfContents):
             para = Paragraph('%s<onDraw name="%s" label="%s"/>' % (text, funcname, len(end_info)), style)
             end_info.append((style, pageNum, key, dot))
             if style.spaceBefore:
-                tableData.append([Spacer(1, style.spaceBefore),])
-            tableData.append([para,])
+                tableData.append([Spacer(1, style.spaceBefore), ])
+            tableData.append([para, ])
 
         self._table = Table(tableData, colWidths=(availWidth,), style=self.tableStyle)
 
-        self.width, self.height = self._table.wrapOn(self.canv,availWidth, availHeight)
+        self.width, self.height = self._table.wrapOn(self.canv, availWidth, availHeight)
         return (self.width, self.height)
 
+
 genelements.MyTableOfContents = DottedTableOfContents
